@@ -1,9 +1,8 @@
 const runscript = require('runscript');
 const path = require('path');
-const assert = require('assert');
 
-describe('test/ts.test.js', function() {
-  it('should works with ts without error', function (done) {
+describe('test/ts.test.js', () => {
+  it('should works with ts without error', done => {
     const cwd = path.resolve(__dirname, './fixtures/ts');
     const tsconfigPath = path.resolve(cwd, 'tsconfig.json');
     const testFile = path.resolve(cwd, 'test');
